﻿Class MainWindow
    Public FileName As String = Nothing, Zoom As Integer = 1, Rotate As Integer = 0

#Region "MainWindow"

    Private Sub MainWindow_Closing(ByVal sender As Object, ByVal e As System.ComponentModel.CancelEventArgs) Handles Me.Closing
        If WindowState = Windows.WindowState.Maximized Then
            My.Settings.MainWindow_IsMax = True
        Else
            My.Settings.MainWindow_IsMax = False
            My.Settings.MainWindow_Loc = New System.Drawing.Size(Left, Top)
            My.Settings.MainWindow_Size = New System.Drawing.Size(My.Settings.MainWindow_Size.Width, My.Settings.MainWindow_Size.Height)
        End If
        My.Settings.Save()
    End Sub

    Private Sub MainWindow_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Input.KeyEventArgs) Handles Me.KeyDown
        If FileName IsNot Nothing Then
            If Keyboard.IsKeyDown(Key.LeftCtrl) OrElse Keyboard.IsKeyDown(Key.RightCtrl) Then
                If e.Key = Key.O Then
                    OpenMenuItem_Click(Nothing, Nothing)
                ElseIf e.Key = Key.P Then
                    PrintMenuItem_Click(Nothing, Nothing)
                ElseIf e.Key = Key.OemPlus Then
                    ZoomInButton_Click(Nothing, Nothing)
                ElseIf e.Key = Key.OemMinus AndAlso ZoomOutButton.IsEnabled Then
                    ZoomOutButton_Click(Nothing, Nothing)
                ElseIf e.Key = Key.NumPad0 Then
                    ResetZoomButton_Click(Nothing, Nothing)
                End If
            End If
        Else
            If Keyboard.IsKeyDown(Key.LeftCtrl) OrElse Keyboard.IsKeyDown(Key.RightCtrl) Then
                If e.Key = Key.O Then
                    OpenMenuItem_Click(Nothing, Nothing)
                End If
            End If
        End If
    End Sub

    Private Sub MainWindow_Loaded(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles Me.Loaded
        If My.Settings.MainWindow_IsMax Then
            WindowState = Windows.WindowState.Maximized
        Else
            Dim l As System.Drawing.Size = My.Settings.MainWindow_Loc
            Left = l.Width
            Top = l.Height
            Dim s As System.Drawing.Size = My.Settings.MainWindow_Size
            Width = s.Width
            Height = s.Height
        End If
        Try
            If My.Application.StartUpFileNames.Count > 0 Then
                For Each s As String In My.Application.StartUpFileNames
                    FileName = s
                    Dim b As New BitmapImage, f As New IO.FileInfo(FileName)
                    b.BeginInit()
                    b.UriSource = New Uri(FileName)
                    b.EndInit()
                    image.Height = b.Height
                    image.Width = b.Width
                    image.Source = b
                    CopyButton.IsEnabled = True
                    ExportMenuItem.IsEnabled = True
                    PrintMenuItem.IsEnabled = True
                    ZoomInButton.IsEnabled = True
                    ResetZoomButton.IsEnabled = True
                    RotateLeftButton.IsEnabled = True
                    RotateRightButton.IsEnabled = True
                    FlipHorizontalButton.IsEnabled = True
                    'FlipVerticalButton.IsEnabled = True
                    Title = f.Name + " - " + My.Application.Info.ProductName
                Next
            End If
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error loading image")
        End Try
    End Sub

#End Region

#Region "MainMenu"

#Region "File"

#Region "Open"

    Private Sub OpenMenuItem_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles OpenMenuItem.Click
        Dim open As New Microsoft.Win32.OpenFileDialog
        open.Filter = "Supported Images(*.bmp;*.gif;*.ico;*jpeg;*.jpg;*.png;*.tif;*.tiff)|*.bmp;*.gif;*.ico;*jpeg;*.jpg;*.png;*.tif;*.tiff|BMP Images(*.bmp)|*.bmp|GIF Images(*.gif)|*.gif|Icon Images(*.ico)|*.ico|JEPG Images(*.jpeg;*.jpg)|*.jpeg;*.jpg|PNG Images(*.png)|*.png|TIFF Images(*.tif;*.tiff)|*.tif;*.tiff|All Files(*.*)|*.*"
        If open.ShowDialog Then
            FileName = open.FileName
            Zoom = 1
            ZoomOutButton.IsEnabled = False
            Rotate = 0
            SetLayout()
            Dim b As New BitmapImage, f As New IO.FileInfo(FileName)
            b.BeginInit()
            b.UriSource = New Uri(FileName)
            b.EndInit()
            image.Height = b.Height
            image.Width = b.Width
            image.Source = b
            CopyButton.IsEnabled = True
            ExportMenuItem.IsEnabled = True
            PrintMenuItem.IsEnabled = True
            ZoomInButton.IsEnabled = True
            ResetZoomButton.IsEnabled = True
            RotateLeftButton.IsEnabled = True
            RotateRightButton.IsEnabled = True
            FlipHorizontalButton.IsEnabled = True
            'FlipVerticalButton.IsEnabled = True
            Title = f.Name + " - " + My.Application.Info.ProductName
        End If
    End Sub

#End Region

#Region "Export"

    Private Sub ExportImageMenuItem_Click(sender As Object, e As RoutedEventArgs) Handles ExportImageMenuItem.Click
        Dim export As New Microsoft.Win32.SaveFileDialog
        export.Filter = "PNG Image(*.png)|*.png|All Files(*.*)|*.*"
        If export.ShowDialog Then
            'TODO:
            Dim bmp As System.Drawing.Image
            bmp = System.Drawing.Image.FromFile(FileName)
            bmp.Save(export.FileName + ".png", System.Drawing.Imaging.ImageFormat.Png)
            bmp.Dispose()
        End If
    End Sub

#Region "Export Xps"

    Private Sub ExportXPSMenuItem_Click1(sender As Object, e As RoutedEventArgs) Handles ExportXPSMenuItem.Click
        Dim d As New Microsoft.Win32.SaveFileDialog
        d.Filter = "XPS Document(*.xps)|*.xps"
        If d.ShowDialog Then
            Dim NewXpsDocument As New Xps.Packaging.XpsDocument(d.FileName + ".xps", IO.FileAccess.ReadWrite)
            Dim xpsw As Xps.XpsDocumentWriter = Xps.Packaging.XpsDocument.CreateXpsDocumentWriter(NewXpsDocument)
            xpsw.Write(image)
            NewXpsDocument.Close()
            xpsw = Nothing
        End If
    End Sub

#End Region

#End Region

#Region "Print"

    Private Sub PrintMenuItem_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles PrintMenuItem.Click
        Dim p As New PrintDialog
        If p.ShowDialog Then
            p.PrintVisual(image, "Image")
        End If
    End Sub

#End Region

    Private Sub ExitMenuItem_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles ExitMenuItem.Click
        Close()
    End Sub

#End Region

#Region "Edit"

    Private Sub CopyMenuItem_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles CopyButton.Click
        Dim bmp As System.Drawing.Image
        bmp = System.Drawing.Image.FromFile(FileName)
        My.Computer.Clipboard.SetImage(bmp)
    End Sub

#End Region

#Region "View"

    Public Sub SetLayout()
        Dim t As New TransformGroup
        Dim z As New ScaleTransform(Zoom, Zoom)
        Dim r As New RotateTransform(Rotate)
        t.Children.Add(z)
        t.Children.Add(r)
        image.LayoutTransform = t
    End Sub

    Private Sub ZoomInButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles ZoomInButton.Click
        Zoom += 1
        If Zoom >= 1 Then
            ZoomOutButton.IsEnabled = True
        End If
        SetLayout()
    End Sub

    Private Sub ZoomOutButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles ZoomOutButton.Click
        Zoom -= 1
        If Zoom = 0 Then
            ZoomOutButton.IsEnabled = False
            Zoom = 1
        ElseIf Zoom = 1 Then
            ZoomOutButton.IsEnabled = False
        Else
            ZoomOutButton.IsEnabled = True
        End If
        SetLayout()
    End Sub

    Private Sub ResetZoomButton_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles ResetZoomButton.Click
        Zoom = 1
        ZoomOutButton.IsEnabled = False
        SetLayout()
    End Sub

    Private Sub RotateLeftButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles RotateLeftButton.Click
        Rotate -= 90
        SetLayout()
    End Sub

    Private Sub RotateRightButton_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles RotateRightButton.Click
        Rotate += 90
        SetLayout()
    End Sub

    Private Sub FlipHorizontalButton_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles FlipHorizontalButton.Click
        If image.FlowDirection = Windows.FlowDirection.LeftToRight Then
            image.FlowDirection = Windows.FlowDirection.RightToLeft
        Else
            image.FlowDirection = Windows.FlowDirection.LeftToRight
        End If
    End Sub

#End Region

    Private Sub AboutMenuItem_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles AboutMenuItem.Click
        Dim a As New AboutDialog
        a.Owner = Me
        a.ShowDialog()
    End Sub

#End Region

    Private Sub FlipVerticalButton_Click(sender As Object, e As System.Windows.RoutedEventArgs) 'Handles FlipVerticalButton.Click
        'TODO:

    End Sub

    Private Sub OptionsMenuItem_Click(sender As Object, e As RoutedEventArgs) Handles OptionsMenuItem.Click
        Dim dialog As New OptionsDialog
        dialog.Owner = Me
        dialog.ShowDialog()
    End Sub
End Class